@@ -355,10 +355,16 @@ readAndUseDeviceInfoDatabase(AGDeviceInfo * devInfo,
         recordid_t id;
         int rc;
 
+#ifdef PILOT_LINK_0_12
+        rc = dlp_ReadRecordByIndex(sd, database_id, 0, 
+                                   (void *)dev_db_info_buffer,
+                                   &id, &attr, &cat);
+#else
         rc = dlp_ReadRecordByIndex(sd, database_id, 0,
                                    (void *)dev_db_info_buffer,
                                    &id, &dev_db_info_buffer_size,
                                    &attr, &cat);
+#endif
 
 
         if (rc >= 0) {
@@ -635,13 +641,17 @@ readDeviceUserConfig32(int userConfigDBHandle, AGUserConfig **deviceUserConfig)
     uint8 buffer[BUFFERSIZE];
     AGBufferReader * r = NULL;
 
+#ifdef PILOT_LINK_0_12
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                               &id, &attr, &cat);
+#else
     rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
                                &id, &bufferSize, &attr, &cat);
+#endif
 
     if (rc < 0) {
 #ifdef _DEBUG
-        printf("readDeviceUserConfig: dlp_ReadRecordByIndex , err = %d\n",
-               rc);
+        printf("readDeviceUserConfig: dlp_ReadRecordByIndex , err = %d\n", rc);
 #endif
         return 0;
     }
@@ -668,8 +678,13 @@ static int32 readDeviceUserConfig31(int userConfigDBHandle,
     uint8 buffer[BUFFERSIZE];
     AGBufferReader * r = NULL;
 
+#ifdef PILOT_LINK_0_12
+    rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                               &id, &attr, &cat);
+#else
     rc = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
                                &id, &bufferSize, &attr, &cat);
+#endif
 
     if (rc < 0) {
 #ifdef _DEBUG
@@ -723,8 +738,13 @@ static void writeDeviceUserConfig(int userConfigDBHandle,
             AGUserConfigWriteData(deviceUserConfig, (AGWriter*)w);
         }
 
+#ifdef PILOT_LINK_0_12
+        result = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
+                                       &id, &attr, &cat);
+#else
         result = dlp_ReadRecordByIndex(sd, userConfigDBHandle, 0, (void *)buffer,
                                        &id, &bufferSize, &attr, &cat);
+#endif
 
         if (result < 0)
             id = 0;
@@ -1006,6 +1026,14 @@ static int32 getRecordBase(PalmSyncInfo * pInfo, AGBool modonly,
     int idx   = pInfo->pilot_RecIndex++;
 
     result = (modonly) ?
+#ifdef PILOT_LINK_0_12
+        dlp_ReadNextModifiedRec (sd, pInfo->pilot_rHandle, pInfo->pilot_buffer,
+                                 &pInfo->id, &idx, &att, &cat)
+        :
+        dlp_ReadRecordByIndex(sd, pInfo->pilot_rHandle, idx,
+                              (void *)pInfo->pilot_buffer,
+                              &pInfo->id, &att, &cat);
+#else
         dlp_ReadNextModifiedRec (sd, pInfo->pilot_rHandle, pInfo->pilot_buffer,
                                  &pInfo->id, &idx,
                                  &size, &att, &cat)
@@ -1013,6 +1041,7 @@ static int32 getRecordBase(PalmSyncInfo * pInfo, AGBool modonly,
         dlp_ReadRecordByIndex(sd, pInfo->pilot_rHandle, idx,
                               pInfo->pilot_buffer, &pInfo->id,
                               &size, &att, &cat);
+#endif
 
     if (result < 0) {
         closeDatabase(pInfo);
